[−][src]Struct hg_parser::ChangesetFile
Changeset's file. Contains path info, internal blob from Mercurial (use file_content for actual file data) and meta information.
Fields
path: Vec<u8>Path.
data: Option<Arc<Vec<u8>>>Data of file, None - file was deleted, otherwise it was added or modified.
manifest_entry: Option<ManifestEntry>Meta information, None - file was deleted, otherwise it was added or modified.